//---------------------------------------------------------------------------

#ifndef RangeMaintFrmH
#define RangeMaintFrmH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <Buttons.hpp>
#include <ExtCtrls.hpp>
#include <swconfig.h>

using namespace sword;
using namespace std;
//---------------------------------------------------------------------------
class TRangeMaintForm : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel4;
	TSpeedButton *SpeedButton3;
	TSpeedButton *SpeedButton4;
	TPanel *Panel2;
	TPanel *Panel1;
	TPanel *Panel3;
	TSpeedButton *SpeedButton1;
	TSpeedButton *SpeedButton2;
	TListBox *ListBox1;
	TPanel *Panel5;
	TLabel *Label1;
	TLabel *Label2;
	TEdit *NameEdit;
	TEdit *TextEdit;
	TPanel *Panel6;
	TListBox *ListBox2;
	TLabel *Label3;
	void __fastcall FormShow(TObject *Sender);
	void __fastcall FormClose(TObject *Sender, TCloseAction &Action);
	void __fastcall SpeedButton4Click(TObject *Sender);
	void __fastcall ListBox1Click(TObject *Sender);
	void __fastcall NameEditChange(TObject *Sender);
	void __fastcall TextEditChange(TObject *Sender);
	void __fastcall SpeedButton2Click(TObject *Sender);
	void __fastcall SpeedButton1Click(TObject *Sender);
	void __fastcall SpeedButton3Click(TObject *Sender);
	void __fastcall Button1Click(TObject *Sender);
private:	// User declarations
	SWConfig *config;
public:		// User declarations
	__fastcall TRangeMaintForm(TComponent* Owner);
};

class TCustomRange : public TObject {
public:
	SWBuf name;
	SWBuf text;
	TCustomRange(const char *name, const char *text) {
		this->name = name;
		this->text = text;
	}
};


//---------------------------------------------------------------------------
extern PACKAGE TRangeMaintForm *RangeMaintForm;
//---------------------------------------------------------------------------
#endif
